@@ -19,7 +19,7 @@ use constant XHTML_ERROR_SEP => "<br />\n";
 
 use Rose::HTML::Form::Constants qw(FF_SEPARATOR);
 
-our $VERSION = '0.549';
+our $VERSION = '0.550';
 
 #our $Debug = 0;
 
@@ -120,17 +120,57 @@ sub invalidate_output_value
 sub parent_field
 {
   my($self) = shift; 
-  return Scalar::Util::weaken($self->{'parent_field'} = shift)  if(@_);
+
+  if(@_)
+  {
+    if(ref $_[0])
+    {
+      Scalar::Util::weaken($self->{'parent_field'} = shift);
+      return $self->{'parent_field'};
+    }
+    else
+    {
+      return $self->{'parent_field'} = shift;
+    }
+  }
+
   return $self->{'parent_field'};
 }
 
 sub parent_form
 {
   my($self) = shift; 
-  return Scalar::Util::weaken($self->{'parent_form'} = shift)  if(@_);
+
+  if(@_)
+  {
+    if(ref $_[0])
+    {
+      Scalar::Util::weaken($self->{'parent_form'} = shift);
+      return $self->{'parent_form'};
+    }
+    else
+    {
+      return $self->{'parent_form'} = shift;
+    }
+  }
+
   return $self->{'parent_form'};
 }
 
+# sub parent_field
+# {
+#   my($self) = shift; 
+#   return Scalar::Util::weaken($self->{'parent_field'} = shift)  if(@_);
+#   return $self->{'parent_field'};
+# }
+# 
+# sub parent_form
+# {
+#   my($self) = shift; 
+#   return Scalar::Util::weaken($self->{'parent_form'} = shift)  if(@_);
+#   return $self->{'parent_form'};
+# }
+
 sub fq_name
 {
   my($self) = shift;
@@ -553,8 +593,11 @@ sub hidden_fields
 
   require Rose::HTML::Form::Field::Hidden; # Circular dependency... :-/
 
-  return Rose::HTML::Form::Field::Hidden->new(
+  return 
+    Rose::HTML::Form::Field::Hidden->new(
       name  => $self->html_attr('name'),
+      id    => $self->html_attr('id'),
+      class => $self->html_attr('class'),
       value => $self->output_value);
 }
 
