@@ -106,7 +106,7 @@ Constructs a new L<Rose::HTML::Form::Field::Password> object based on PARAMS, wh
 
 =head1 AUTHOR
 
-John C. Siracusa (siracusa@mindspring.com)
+John C. Siracusa (siracusa@gmail.com)
 
 =head1 COPYRIGHT
 
